Coverage for curator/exceptions.py: 100%

1"""Curator Exceptions"""

2 class CuratorException(Exception):

3 """

4 Base class for all exceptions raised by Curator which are not Elasticsearch

5 exceptions.

6 """

7

8 class ConfigurationError(CuratorException):

9 """

10 Exception raised when a misconfiguration is detected

11 """

12

13 class MissingArgument(CuratorException):

14 """

15 Exception raised when a needed argument is not passed.

16 """

17

18 class NoIndices(CuratorException):

19 """

20 Exception raised when an operation is attempted against an empty index_list

21 """

22

23 class NoSnapshots(CuratorException):

24 """

25 Exception raised when an operation is attempted against an empty snapshot_list

26 """

27

28 class ActionError(CuratorException):

29 """

30 Exception raised when an action (against an index_list or snapshot_list) cannot be taken.

31 """

32

33 class FailedExecution(CuratorException):

34 """

35 Exception raised when an action fails to execute for some reason.

36 """

37

38 class SnapshotInProgress(ActionError):

39 """

40 Exception raised when a snapshot is already in progress

41 """

42

43 class ActionTimeout(CuratorException):

44 """

45 Exception raised when an action fails to complete in the allotted time

46 """

47

48 class FailedSnapshot(CuratorException):

49 """

50 Exception raised when a snapshot does not complete with state SUCCESS

51 """

52

53 class FailedRestore(CuratorException):

54 """

55 Exception raised when a Snapshot Restore does not restore all selected indices

56 """

57

58 class FailedReindex(CuratorException):

59 """

60 Exception raised when failures are found in the reindex task response

61 """

62

63 class ClientException(CuratorException):

64 """

65 Exception raised when the Elasticsearch client and/or connection is the source of the problem.

66 """

67

68 class LoggingException(CuratorException):

69 """

70 Exception raised when Curator cannot either log or configure logging

71 """